package Locale::CLDR::Km::Any v0.25.0;
# This file auto generated
#	on Mon 21 Apr 11:31:52 pm GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Km');

no Moose;
__PACKAGE__->meta->make_immutable;
